@@ -35,6 +35,8 @@ from pensando_dss.psm.model.cluster_auto_msg_dsc_profile_watch_helper import Clu
 from pensando_dss.psm.model.cluster_auto_msg_dsc_profile_watch_helper_watch_event import ClusterAutoMsgDSCProfileWatchHelperWatchEvent
 from pensando_dss.psm.model.cluster_auto_msg_distributed_service_card_watch_helper import ClusterAutoMsgDistributedServiceCardWatchHelper
 from pensando_dss.psm.model.cluster_auto_msg_distributed_service_card_watch_helper_watch_event import ClusterAutoMsgDistributedServiceCardWatchHelperWatchEvent
+from pensando_dss.psm.model.cluster_auto_msg_distributed_service_entity_watch_helper import ClusterAutoMsgDistributedServiceEntityWatchHelper
+from pensando_dss.psm.model.cluster_auto_msg_distributed_service_entity_watch_helper_watch_event import ClusterAutoMsgDistributedServiceEntityWatchHelperWatchEvent
 from pensando_dss.psm.model.cluster_auto_msg_host_watch_helper import ClusterAutoMsgHostWatchHelper
 from pensando_dss.psm.model.cluster_auto_msg_host_watch_helper_watch_event import ClusterAutoMsgHostWatchHelperWatchEvent
 from pensando_dss.psm.model.cluster_auto_msg_license_watch_helper import ClusterAutoMsgLicenseWatchHelper
@@ -80,9 +82,14 @@ from pensando_dss.psm.model.cluster_distributed_service_card_id import ClusterDi
 from pensando_dss.psm.model.cluster_distributed_service_card_list import ClusterDistributedServiceCardList
 from pensando_dss.psm.model.cluster_distributed_service_card_spec import ClusterDistributedServiceCardSpec
 from pensando_dss.psm.model.cluster_distributed_service_card_status import ClusterDistributedServiceCardStatus
+from pensando_dss.psm.model.cluster_distributed_service_entity import ClusterDistributedServiceEntity
+from pensando_dss.psm.model.cluster_distributed_service_entity_list import ClusterDistributedServiceEntityList
+from pensando_dss.psm.model.cluster_distributed_service_entity_spec import ClusterDistributedServiceEntitySpec
+from pensando_dss.psm.model.cluster_distributed_service_entity_status import ClusterDistributedServiceEntityStatus
 from pensando_dss.psm.model.cluster_fault import ClusterFault
 from pensando_dss.psm.model.cluster_feature import ClusterFeature
 from pensando_dss.psm.model.cluster_feature_status import ClusterFeatureStatus
+from pensando_dss.psm.model.cluster_flow_export_policy_ref import ClusterFlowExportPolicyRef
 from pensando_dss.psm.model.cluster_fwlog_policy_ref import ClusterFwlogPolicyRef
 from pensando_dss.psm.model.cluster_host import ClusterHost
 from pensando_dss.psm.model.cluster_host_list import ClusterHostList
@@ -95,13 +102,17 @@ from pensando_dss.psm.model.cluster_license_list import ClusterLicenseList
 from pensando_dss.psm.model.cluster_license_spec import ClusterLicenseSpec
 from pensando_dss.psm.model.cluster_license_status import ClusterLicenseStatus
 from pensando_dss.psm.model.cluster_mem_info import ClusterMemInfo
+from pensando_dss.psm.model.cluster_neighbor_port_info import ClusterNeighborPortInfo
 from pensando_dss.psm.model.cluster_node import ClusterNode
 from pensando_dss.psm.model.cluster_node_condition import ClusterNodeCondition
 from pensando_dss.psm.model.cluster_node_list import ClusterNodeList
 from pensando_dss.psm.model.cluster_node_spec import ClusterNodeSpec
 from pensando_dss.psm.model.cluster_node_status import ClusterNodeStatus
 from pensando_dss.psm.model.cluster_os_info import ClusterOsInfo
+from pensando_dss.psm.model.cluster_overlay_forwarding import ClusterOverlayForwarding
+from pensando_dss.psm.model.cluster_peer import ClusterPeer
 from pensando_dss.psm.model.cluster_peer_status import ClusterPeerStatus
+from pensando_dss.psm.model.cluster_pnic_info import ClusterPnicInfo
 from pensando_dss.psm.model.cluster_policer_ref import ClusterPolicerRef
 from pensando_dss.psm.model.cluster_propagation_status import ClusterPropagationStatus
 from pensando_dss.psm.model.cluster_quorum_member_condition import ClusterQuorumMemberCondition
