@@ -27,6 +27,7 @@ from pensando_dss.psm.model.api_watch_event import ApiWatchEvent
 from pensando_dss.psm.model.api_watch_event_list import ApiWatchEventList
 from pensando_dss.psm.model.cluster_ip_config import ClusterIPConfig
 from pensando_dss.psm.model.googleprotobuf_any import GoogleprotobufAny
+from pensando_dss.psm.model.network_add_static_bindings_request import NetworkAddStaticBindingsRequest
 from pensando_dss.psm.model.network_auto_msg_ipam_policy_watch_helper import NetworkAutoMsgIPAMPolicyWatchHelper
 from pensando_dss.psm.model.network_auto_msg_ipam_policy_watch_helper_watch_event import NetworkAutoMsgIPAMPolicyWatchHelperWatchEvent
 from pensando_dss.psm.model.network_auto_msg_lb_policy_watch_helper import NetworkAutoMsgLbPolicyWatchHelper
@@ -50,21 +51,27 @@ from pensando_dss.psm.model.network_auto_msg_virtual_router_watch_helper_watch_e
 from pensando_dss.psm.model.network_bgp_auth_status import NetworkBGPAuthStatus
 from pensando_dss.psm.model.network_bgp_config import NetworkBGPConfig
 from pensando_dss.psm.model.network_bgp_neighbor import NetworkBGPNeighbor
+from pensando_dss.psm.model.network_bootstrap_ipam_options import NetworkBootstrapIPAMOptions
+from pensando_dss.psm.model.network_classless_static_route import NetworkClasslessStaticRoute
 from pensando_dss.psm.model.network_dhcp_relay_policy import NetworkDHCPRelayPolicy
 from pensando_dss.psm.model.network_dhcp_server import NetworkDHCPServer
 from pensando_dss.psm.model.network_health_check_spec import NetworkHealthCheckSpec
+from pensando_dss.psm.model.network_ipam_binding import NetworkIPAMBinding
 from pensando_dss.psm.model.network_ipam_config import NetworkIPAMConfig
+from pensando_dss.psm.model.network_ipam_options import NetworkIPAMOptions
 from pensando_dss.psm.model.network_ipam_policy import NetworkIPAMPolicy
 from pensando_dss.psm.model.network_ipam_policy_list import NetworkIPAMPolicyList
 from pensando_dss.psm.model.network_ipam_policy_spec import NetworkIPAMPolicySpec
 from pensando_dss.psm.model.network_ipam_policy_status import NetworkIPAMPolicyStatus
 from pensando_dss.psm.model.network_ipam_pool_info import NetworkIPAMPoolInfo
+from pensando_dss.psm.model.network_interface_ip import NetworkInterfaceIP
 from pensando_dss.psm.model.network_lldp_neighbor import NetworkLLDPNeighbor
 from pensando_dss.psm.model.network_lb_policy import NetworkLbPolicy
 from pensando_dss.psm.model.network_lb_policy_list import NetworkLbPolicyList
 from pensando_dss.psm.model.network_lb_policy_spec import NetworkLbPolicySpec
 from pensando_dss.psm.model.network_lb_policy_status import NetworkLbPolicyStatus
 from pensando_dss.psm.model.network_network import NetworkNetwork
+from pensando_dss.psm.model.network_network_firewall_profile import NetworkNetworkFirewallProfile
 from pensando_dss.psm.model.network_network_interface import NetworkNetworkInterface
 from pensando_dss.psm.model.network_network_interface_host_status import NetworkNetworkInterfaceHostStatus
 from pensando_dss.psm.model.network_network_interface_list import NetworkNetworkInterfaceList
@@ -82,6 +89,7 @@ from pensando_dss.psm.model.network_policer_profile import NetworkPolicerProfile
 from pensando_dss.psm.model.network_policer_profile_list import NetworkPolicerProfileList
 from pensando_dss.psm.model.network_policer_profile_spec import NetworkPolicerProfileSpec
 from pensando_dss.psm.model.network_policer_profile_status import NetworkPolicerProfileStatus
+from pensando_dss.psm.model.network_policy_reference import NetworkPolicyReference
 from pensando_dss.psm.model.network_rd_spec import NetworkRDSpec
 from pensando_dss.psm.model.network_route import NetworkRoute
 from pensando_dss.psm.model.network_route_distinguisher import NetworkRouteDistinguisher
@@ -92,6 +100,7 @@ from pensando_dss.psm.model.network_routing_config import NetworkRoutingConfig
 from pensando_dss.psm.model.network_routing_config_list import NetworkRoutingConfigList
 from pensando_dss.psm.model.network_routing_config_spec import NetworkRoutingConfigSpec
 from pensando_dss.psm.model.network_routing_config_status import NetworkRoutingConfigStatus
+from pensando_dss.psm.model.network_security_policy_status import NetworkSecurityPolicyStatus
 from pensando_dss.psm.model.network_service import NetworkService
 from pensando_dss.psm.model.network_service_list import NetworkServiceList
 from pensando_dss.psm.model.network_service_spec import NetworkServiceSpec
